==> migrate_wizard-2.0.6-alpha1.tar.gz: migrate_wizard/src/EventSubscriber/MWPostRowUserSubscriber.php <==
<?php

namespace Drupal\migrate_wizard\EventSubscriber;

use Drupal\cas\Service\CasUserManager;
use Drupal\Core\Database\Connection;
use Drupal\Core\Database\Query\SelectInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Language\LanguageInterface;
use Drupal\migrate\Event\MigrateEvents;
use Drupal\migrate\Event\MigratePostRowSaveEvent;
use Drupal\migrate\Event\MigratePreRowSaveEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * This class is executed after row is saved.
 */
class MWPostRowUserSubscriber implements EventSubscriberInterface {

    /**
   * The entity type manager.
   *
   * @var Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;
  /**
   * Constructs a new migration subscriber.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity field manager service.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, Connection $connection) {
    $this->entityTypeManager = $entity_type_manager;
    $this->connection = $connection;
  }
  public function postRowUser(MigratePostRowSaveEvent $event) {
      $this->setCasUserName($event);
      $this->checkDuplicateAlias($event);
  }
  /**
   * Set the CAS user name to the user name entity after migrate.
   */
  public function setCasUserName(MigratePostRowSaveEvent $event) {
    $source_config = $event->getMigration()->getSourceConfiguration();
    if ($source_config["bundle"] == "user" && isset($source_config["import_cas"]) && $source_config["import_cas"]) {
      $casUserManager = \Drupal::service('cas.user_manager');
      $row = $event->getRow();
      $cas_name = $row->getSourceProperty("cas_name");
      if (!empty($cas_name)) {
        $destination_uids = $event->getDestinationIdValues();
        $new_uid = end($destination_uids);
        $account = $this->entityTypeManager
          ->getStorage('user')
          ->load($new_uid);
        $casUserManager->setCasUsernameForAccount($account, $cas_name);
      }
    }
  }

  public function checkDuplicateAlias(MigratePreRowSaveEvent $event) {
    $row = $event->getRow();
    if($row->getSourceProperty('alias') != null){
      $path_alias_repository = \Drupal::service('path_alias.repository');
      $existing_alias = $this->deleteDuplicatedAlias($row->getSourceProperty('alias'), $row->getSourceProperty('language'));

    }
  }
  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[MigrateEvents::POST_ROW_SAVE][] = ['setCasUserName', 0];
    $events[MigrateEvents::PRE_ROW_SAVE][] = ['checkDuplicateAlias', 0];
    return $events;
  }

    /**
   * {@inheritdoc}
   */
  private function deleteDuplicatedAlias($alias, $langcode) {
    // See the queries above. Use LIKE for case-insensitive matching.
    $select = $this->getBaseQuery()
      ->condition('path_alias.alias', $this->connection->escapeLike($alias), 'LIKE');

    $select->condition('path_alias.langcode', $langcode, 'IN');

    $existing_alias = $select->execute() ?: NULL;
  }

    /**
   * Returns a SELECT query for the path_alias base table.
   *
   * @return \Drupal\Core\Database\Query\SelectInterface
   *   A Select query object.
   */
  protected function getBaseQuery() {
    $query = $this->connection->delete('path_alias', );
    $query->condition('path_alias.status', 1);

    return $query;
  }
}

==> migrate_wizard-2.0.7-alpha1.tar.gz: migrate_wizard/src/EventSubscriber/MWPostRowUserSubscriber.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\EventSubscriber;

use Drupal\cas\Service\CasUserManager;
use Drupal\Core\Database\Connection;
use Drupal\Core\Database\Query\SelectInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Language\LanguageInterface;
use Drupal\migrate\Event\MigrateEvents;
use Drupal\migrate\Event\MigratePostRowSaveEvent;
use Drupal\migrate\Event\MigratePreRowSaveEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * This class is executed after row is saved.
 */
class MWPostRowUserSubscriber implements EventSubscriberInterface {

    /**
   * The entity type manager.
   *
   * @var Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;
  /**
   * Constructs a new migration subscriber.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity field manager service.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, Connection $connection) {
    $this->entityTypeManager = $entity_type_manager;
    $this->connection = $connection;
  }
  public function postRowUser(MigratePostRowSaveEvent $event) {
      $this->setCasUserName($event);
      $this->checkDuplicateAlias($event);
  }
  /**
   * Set the CAS user name to the user name entity after migrate.
   */
  public function setCasUserName(MigratePostRowSaveEvent $event) {
    $source_config = $event->getMigration()->getSourceConfiguration();
    if (isset($source_config["bundle"]) && $source_config["bundle"] == "user" && isset($source_config["import_cas"]) && $source_config["import_cas"]) {
      $casUserManager = \Drupal::service('cas.user_manager');
      $row = $event->getRow();
      $cas_name = $row->getSourceProperty("cas_name");
      if (!empty($cas_name)) {
        $destination_uids = $event->getDestinationIdValues();
        $new_uid = end($destination_uids);
        $account = $this->entityTypeManager
          ->getStorage('user')
          ->load($new_uid);
        $casUserManager->setCasUsernameForAccount($account, $cas_name);
      }
    }
  }

  public function checkDuplicateAlias(MigratePreRowSaveEvent $event) {
    $row = $event->getRow();
    if($row->getSourceProperty('alias') != null){
      $path_alias_repository = \Drupal::service('path_alias.repository');
      $existing_alias = $this->deleteDuplicatedAlias($row->getSourceProperty('alias'), $row->getSourceProperty('language'));

    }
  }
  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[MigrateEvents::POST_ROW_SAVE][] = ['setCasUserName', 0];
    $events[MigrateEvents::PRE_ROW_SAVE][] = ['checkDuplicateAlias', 0];
    return $events;
  }

    /**
   * {@inheritdoc}
   */
  private function deleteDuplicatedAlias($alias, $langcode) {
    // See the queries above. Use LIKE for case-insensitive matching.
    $select = $this->getBaseQuery()
      ->condition('path_alias.alias', $this->connection->escapeLike($alias), 'LIKE');

    $select->condition('path_alias.langcode', $langcode, 'IN');

    $existing_alias = $select->execute() ?: NULL;
  }

    /**
   * Returns a SELECT query for the path_alias base table.
   *
   * @return \Drupal\Core\Database\Query\SelectInterface
   *   A Select query object.
   */
  protected function getBaseQuery() {
    $query = $this->connection->delete('path_alias', );
    $query->condition('path_alias.status', 1);

    return $query;
  }
}
